from distutils.core import setup

setup(
        name    ='n_again',
        version ='1.0.0',
        py_modules =['n_again'],
        authon  ='hfpython',
        authon_email='hfpython@headfirstlabs.com',
        url     ='http://www.jeadfirstlabs.com',
        description='A simple printer of nested lists',
    )
